@@ -1,7 +1,7 @@
 # **************************************************************************
 # *
-# * Authors: Peter Horvath [1]
-# *          Pablo Conesa [1]
+# * Authors: Peter Horvath (phorvath@cnb.csic.es) [1]
+# *          Pablo Conesa (pconesa@cnb.csic.es) [1]
 # *
 # * [1] I2PC center
 # *
@@ -26,12 +26,9 @@
 # **************************************************************************
 
 import os
-import csv
-import re
-import emtable
+from emtable import Table
 
 import pyworkflow.utils as pwutils
-import pwem.objects as emobj
 from pwem.emlib.image import ImageHandler
 from pwem.convert import Ccp4Header
 
@@ -75,7 +72,7 @@ class CoordBoxWriter:
 
 
 class CoordBoxReader:
-    """ Helper class to read coordinates from .BOX files. """
+    """ Helper class to read coordinates from .CBOX files. """
     def __init__(self, boxSize, yFlipHeight=None, boxSizeEstimated=False):
         """
         :param boxSize: The box size of the coordinates that will be read
@@ -87,74 +84,12 @@ class CoordBoxReader:
         self._yFlipHeight = yFlipHeight
         self._boxSizeEstimated = boxSizeEstimated
 
-    def open(self, filename):
-        """ Open a new filename to write, close previous one if open. """
-        self.close()
-        self._file = open(filename, 'r')
-
-    def _getDataLength(self):
-        try:
-            head = next(self._file)  # Read the first line
-            cols = re.split(r'\t+', head.rstrip('\t'))  # Strip it by tab
-            self._file.seek(0)  # Return to the top of the file
-            return len(cols)
-        except StopIteration:
-            return None
-
-    def iterCoords(self):
-        reader = csv.reader(self._file, delimiter='\t')
-
-        if self._getDataLength() == 7:  # crYOLO generates .cbox files with 7 columns from version > 1.5.4
-            for x, y, _, _, score, _, _ in reader:
-                # USE the imageHeight to flip or not to flip!
-                sciX = float(x)
-                sciY = float(y)
-
-                if not self._boxSizeEstimated:
-                    sciX += self._halfBox
-                    sciY += self._halfBox
-
-                if self._yFlipHeight is not None:
-                    sciY = self._yFlipHeight - sciY
-
-                yield round(sciX), round(sciY), float(score)
-
-        elif self._getDataLength() == 5:   # crYOLO generates .cbox files with 4 columns from version <= 1.5.4
-            for x, y, _, _, score in reader:
-                # USE the imageHeight to flip or not to flip!
-                sciX = round(float(x) + self._halfBox)
-                sciY = round(float(y) + self._halfBox)
-
-                if self._yFlipHeight is not None:
-                    sciY = self._yFlipHeight - sciY
-
-                yield sciX, sciY, float(score)
-
-        else:  # crYOLO generates .cbox files with 11 columns from version = 1.8.0
-            table = emtable.Table(fileName=self._file.name)
-            for row in table.iterRows(self._file.name, tableName='cryolo'):
-                x = float(row.CoordinateX)
-                y = float(row.CoordinateY)
-                score = float(row.Confidence)
-
-                if not self._boxSizeEstimated:
-                    x += self._halfBox
-                    y += self._halfBox
-
-                sciX = round(x)
-                sciY = round(y)
-
-                if self._yFlipHeight is not None:
-                    sciY = self._yFlipHeight - sciY
-
-                yield sciX, sciY, score
-
-    def  iter3DCoords(self):
-        table = emtable.Table(fileName=self._file.name)
-        for row in table.iterRows(self._file.name, tableName='cryolo'):
-            x = float(row.CoordinateX)
-            y = float(row.CoordinateY)
-            z = float(row.CoordinateZ)
+    def iterCoords(self, filename):
+        for row in Table.iterRows(filename, tableName='cryolo'):
+            x = row.CoordinateX
+            y = row.CoordinateY
+            z = row.get("CoordinateZ", 0.0)
+            score = row.get("Confidence", 0.0)
 
             if not self._boxSizeEstimated:
                 x += self._halfBox
@@ -162,16 +97,12 @@ class CoordBoxReader:
 
             sciX = round(x)
             sciY = round(y)
-            sciZ = round(z)
+            sciZ = round(z) if not isinstance(z, str) else 0  # avoid <NA> values
 
             if self._yFlipHeight is not None:
                 sciY = self._yFlipHeight - sciY
 
-            yield sciX, sciY, sciZ
-
-    def close(self):
-        if self._file:
-            self._file.close()
+            yield sciX, sciY, sciZ, score
 
 
 def writeSetOfCoordinates(boxDir, coordSet, micList=None):
@@ -203,8 +134,7 @@ def writeSetOfCoordinates(boxDir, coordSet, micList=None):
         if micId != lastMicId:
             doWrite = micId in micIdSet
             if doWrite:
-                # we need to close previous opened file
-                writer.open(os.path.join(boxDir, getMicIdName(mic, suffix='.box')))
+                writer.open(os.path.join(boxDir, getMicFn(mic, "box")))
             lastMicId = micId
 
         if doWrite:
@@ -216,26 +146,21 @@ def writeSetOfCoordinates(boxDir, coordSet, micList=None):
 def readSetOfCoordinates3D(tomogram, coord3DSetDict, coordsFile, boxSize,
                            origin=None):
     reader = CoordBoxReader(boxSize)
-    reader.open(coordsFile)
-
     coord3DSet = coord3DSetDict[tomogram.getObjId()]
     coord3DSet.enableAppend()
 
     coord = Coordinate3D()
 
-    for x, y, z in reader.iter3DCoords():
+    for x, y, z, _ in reader.iterCoords(coordsFile):
         # Clean up objId to add as a new coordinate
         coord.setObjId(None)
         coord.setVolume(tomogram)
         coord.setPosition(x, y, z, origin)
-        # Add it to the set
         coord3DSet.append(coord)
 
-    reader.close()
-
 
 def needToFlipOnY(filename):
-    """ Returns true if need to flip coordinates on Y"""
+    """ Returns true if we need to flip coordinates on Y"""
     ext = pwutils.getExt(filename)
 
     if ext in ".mrc":
@@ -251,7 +176,7 @@ def getFlipYHeight(filename):
     return y if needToFlipOnY(filename) else None
 
 
-def convertMicrographs(micList, micDir, prefix='mic'):
+def convertMicrographs(micList, micDir):
     """ Convert (or simply link) input micrographs into the given directory
     in a format that is compatible with crYOLO.
     """
@@ -272,29 +197,19 @@ def convertMicrographs(micList, micDir, prefix='mic'):
         ext = '.mrc'
 
     for mic in micList:
-        func(mic, getMicIdName(mic, prefix=prefix, suffix=ext))
+        func(mic, getMicFn(mic, ext.lstrip(".")))
 
 
-def convertTomograms(micList, micDir):
-    prefix = pwutils.removeBaseExt(micList[0].getFileName())
-    convertMicrographs(micList, micDir, prefix=prefix)
-
-
-def getMicIdName(mic, prefix='mic', suffix=''):
-    """ Return a name for the micrograph based on its IDs. """
-    return '%s%05d%s' % (prefix, mic.getObjId(), suffix)
+def getMicFn(mic, ext='mrc'):
+    """ Return a name for the micrograph based on its filename. """
+    return pwutils.replaceBaseExt(mic.getFileName(), ext)
 
 
 def roundInputSize(inputSize):
     """ Returns the closest value to inputSize th is multiple of 32"""
-    rounded = roundTo(inputSize, 32)
+    rounded = int(32 * round(float(inputSize) / 32))
 
     if rounded != inputSize:
         print("Input size (%s) will be rounded to %s, the closest "
               "multiple of 32." % (inputSize, rounded))
     return rounded
-
-
-def roundTo(number, base=1.0):
-    """ Returns the closest int value to number that is multiple of base"""
-    return int(base * round(float(number) / base))
